@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2012 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -81,7 +81,7 @@ static gboolean stream_eos (GMimeStream *stream);
 static int stream_reset (GMimeStream *stream);
 static gint64 stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence);
 static gint64 stream_tell (GMimeStream *stream);
-static ssize_t stream_length (GMimeStream *stream);
+static gint64 stream_length (GMimeStream *stream);
 static GMimeStream *stream_substream (GMimeStream *stream, gint64 start, gint64 end);
 
 
@@ -185,7 +185,7 @@ stream_read (GMimeStream *stream, char *buf, size_t n)
 	priv->last_was_read = TRUE;
 	
 	if (priv->filteredlen <= 0) {
-		size_t presize = READ_PAD;
+		size_t presize = READ_SIZE;
 		
 		nread = g_mime_stream_read (filter->source, priv->buffer, READ_SIZE);
 		if (nread <= 0) {
@@ -352,7 +352,7 @@ stream_tell (GMimeStream *stream)
 	return -1;
 }
 
-static ssize_t
+static gint64
 stream_length (GMimeStream *stream)
 {
 	return stream->bound_end - stream->bound_start;
